@@ -10,7 +10,8 @@ from django.contrib.admin.views import main
 from django.contrib.admin.actions import delete_selected
 from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.db.models import Q
-from django.http import (HttpResponse, HttpResponseBadRequest,
+from django.http import (
+    HttpResponse, HttpResponseBadRequest,
     HttpResponseForbidden, HttpResponseNotFound, HttpResponseServerError)
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
@@ -41,8 +42,8 @@ def django_boolean_icon(field_val, alt_text=None, title=None):
     else:
         title = ''
     icon_url = static('feincms/img/icon-%s.gif' % BOOLEAN_MAPPING[field_val])
-    return mark_safe(u'<img src="%s" alt="%s" %s/>' %
-            (icon_url, alt_text, title))
+    return mark_safe(
+        u'<img src="%s" alt="%s" %s/>' % (icon_url, alt_text, title))
 
 
 def _build_tree_structure(queryset):
@@ -109,12 +110,12 @@ def ajax_editable_boolean_cell(item, attr, text='', override=None):
     else:
         value = getattr(item, attr)
         a = [
-            '<input type="checkbox"',
-            value and ' checked="checked"' or '',
-            ' onclick="inplace_toggle_boolean(%d, \'%s\').then($.fn.recolorRows);"' % (item.pk, attr),
-            ' />',
-            text,
-            ]
+            '<input type="checkbox" data-inplace data-inplace-id="%s"'
+            ' data-inplace-attribute="%s" %s>' % (
+                item.pk,
+                attr,
+                'checked="checked"' if value else '',
+            )]
 
     a.insert(0, '<div id="wrap_%s_%d">' % (attr, item.pk))
     a.append('</div>')
@@ -164,15 +165,17 @@ class ChangeList(main.ChangeList):
     def get_results(self, request):
         mptt_opts = self.model._mptt_meta
         if settings.FEINCMS_TREE_EDITOR_INCLUDE_ANCESTORS:
-            clauses = [Q(**{mptt_opts.tree_id_attr: tree_id,
-                            mptt_opts.left_attr + '__lte': lft,
-                            mptt_opts.right_attr + '__gte': rght,
-                            })
-                    for lft, rght, tree_id in self.query_set.values_list(
-                        mptt_opts.left_attr,
-                        mptt_opts.right_attr,
-                        mptt_opts.tree_id_attr,
-                    )]
+            clauses = [
+                Q(**{
+                    mptt_opts.tree_id_attr: tree_id,
+                    mptt_opts.left_attr + '__lte': lft,
+                    mptt_opts.right_attr + '__gte': rght,
+                }) for lft, rght, tree_id in self.query_set.values_list(
+                    mptt_opts.left_attr,
+                    mptt_opts.right_attr,
+                    mptt_opts.tree_id_attr,
+                )
+            ]
             # We could optimise a bit here by explicitely filtering out
             # any clauses that are for parents of nodes included in the
             # queryset anyway. (ie: drop all clauses that refer to a node
@@ -216,8 +219,9 @@ class TreeEditor(ExtensionModelAdmin):
     form = MPTTAdminForm
 
     if settings.FEINCMS_TREE_EDITOR_INCLUDE_ANCESTORS:
-        # Make sure that no pagination is displayed. Slicing is disabled anyway,
-        # therefore this value does not have an influence on the queryset
+        # Make sure that no pagination is displayed. Slicing is disabled
+        # anyway, therefore this value does not have an influence on the
+        # queryset
         list_per_page = 999999999
 
     def __init__(self, *args, **kwargs):
@@ -234,13 +238,17 @@ class TreeEditor(ExtensionModelAdmin):
 
         opts = self.model._meta
         self.change_list_template = [
-            'admin/feincms/%s/%s/tree_editor.html' % (opts.app_label, opts.object_name.lower()),
+            'admin/feincms/%s/%s/tree_editor.html' % (
+                opts.app_label, opts.object_name.lower()),
             'admin/feincms/%s/tree_editor.html' % opts.app_label,
             'admin/feincms/tree_editor.html',
-            ]
-        self.object_change_permission = opts.app_label + '.' + opts.get_change_permission()
-        self.object_add_permission = opts.app_label + '.' + opts.get_add_permission()
-        self.object_delete_permission = opts.app_label + '.' + opts.get_delete_permission()
+        ]
+        self.object_change_permission =\
+            opts.app_label + '.' + opts.get_change_permission()
+        self.object_add_permission =\
+            opts.app_label + '.' + opts.get_add_permission()
+        self.object_delete_permission =\
+            opts.app_label + '.' + opts.get_delete_permission()
 
     def changeable(self, item):
         return getattr(item, 'feincms_changeable', True)
@@ -308,7 +316,8 @@ class TreeEditor(ExtensionModelAdmin):
                     result_func = item.editable_boolean_result
                 else:
                     def _fn(attr):
-                        return lambda self, instance: [ajax_editable_boolean_cell(instance, attr)]
+                        return lambda self, instance: [
+                            ajax_editable_boolean_cell(instance, attr)]
                     result_func = _fn(attr)
                 self._ajax_editable_booleans[attr] = result_func
 
@@ -317,7 +326,8 @@ class TreeEditor(ExtensionModelAdmin):
         Refresh information used to show the changelist tree structure such as
         inherited active/inactive states etc.
 
-        XXX: This is somewhat hacky, but since it's an internal method, so be it.
+        XXX: This is somewhat hacky, but since it's an internal method, so be
+        it.
         """
 
         pass
@@ -333,8 +343,11 @@ class TreeEditor(ExtensionModelAdmin):
             return HttpResponseBadRequest("Malformed request")
 
         if not request.user.is_staff:
-            logger.warning("Denied AJAX request by non-staff \"%s\" to toggle boolean %s for object #%s", request.user, attr, item_id)
-            return HttpResponseForbidden(_("You do not have permission to modify this object"))
+            logger.warning(
+                "Denied AJAX request by non-staff \"%s\" to toggle boolean"
+                " %s for object #%s", request.user, attr, item_id)
+            return HttpResponseForbidden(
+                _("You do not have permission to modify this object"))
 
         self._collect_editable_booleans()
 
@@ -347,11 +360,15 @@ class TreeEditor(ExtensionModelAdmin):
             return HttpResponseNotFound("Object does not exist")
 
         if not self.has_change_permission(request, obj=obj):
-            logger.warning("Denied AJAX request by \"%s\" to toggle boolean %s for object %s", request.user, attr, item_id)
-            return HttpResponseForbidden(_("You do not have permission to modify this object"))
+            logger.warning(
+                "Denied AJAX request by \"%s\" to toggle boolean %s for"
+                " object %s", request.user, attr, item_id)
+            return HttpResponseForbidden(
+                _("You do not have permission to modify this object"))
 
         new_state = not getattr(obj, attr)
-        logger.info("Toggle %s on #%d %s to %s by \"%s\"",
+        logger.info(
+            "Toggle %s on #%d %s to %s by \"%s\"",
             attr, obj.pk, obj, "on" if new_state else "off", request.user)
 
         try:
@@ -367,15 +384,17 @@ class TreeEditor(ExtensionModelAdmin):
             data = self._ajax_editable_booleans[attr](self, obj)
 
         except Exception:
-            logger.exception("Unhandled exception while toggling %s on %s", attr, obj)
-            return HttpResponseServerError("Unable to toggle %s on %s" % (attr, obj))
+            logger.exception(
+                "Unhandled exception while toggling %s on %s", attr, obj)
+            return HttpResponseServerError(
+                "Unable to toggle %s on %s" % (attr, obj))
 
         # Weed out unchanged cells to keep the updates small. This assumes
         # that the order a possible get_descendents() returns does not change
         # before and after toggling this attribute. Unlikely, but still...
-        return HttpResponse(json.dumps(
-            [b for a, b in zip(before_data, data) if a != b]
-            ), content_type="application/json")
+        return HttpResponse(
+            json.dumps([b for a, b in zip(before_data, data) if a != b]),
+            content_type="application/json")
 
     def get_changelist(self, request, **kwargs):
         return ChangeList
@@ -396,17 +415,18 @@ class TreeEditor(ExtensionModelAdmin):
                 return self._toggle_boolean(request)
             elif cmd == 'move_node':
                 return self._move_node(request)
-            else:
-                return HttpResponseBadRequest('Oops. AJAX request not understood.')
+
+            return HttpResponseBadRequest('Oops. AJAX request not understood.')
 
         self._refresh_changelist_caches()
 
         extra_context = extra_context or {}
         queryset = self.queryset(request)
-        extra_context['tree_structure'] = mark_safe(json.dumps(
-                                                    _build_tree_structure(queryset)))
+        extra_context['tree_structure'] = mark_safe(
+            json.dumps(_build_tree_structure(queryset)))
 
-        return super(TreeEditor, self).changelist_view(request, extra_context, *args, **kwargs)
+        return super(TreeEditor, self).changelist_view(
+            request, extra_context, *args, **kwargs)
 
     def has_add_permission(self, request, obj=None):
         """
@@ -432,7 +452,8 @@ class TreeEditor(ExtensionModelAdmin):
         else:
             r = request.user.has_perm(perm)
 
-        return r and super(TreeEditor, self).has_change_permission(request, obj)
+        return r and super(TreeEditor, self).has_change_permission(
+            request, obj)
 
     def has_delete_permission(self, request, obj=None):
         """
@@ -445,7 +466,8 @@ class TreeEditor(ExtensionModelAdmin):
         else:
             r = request.user.has_perm(perm)
 
-        return r and super(TreeEditor, self).has_delete_permission(request, obj)
+        return r and super(TreeEditor, self).has_delete_permission(
+            request, obj)
 
     def _move_node(self, request):
         if hasattr(self.model.objects, 'move_node'):
@@ -475,9 +497,9 @@ class TreeEditor(ExtensionModelAdmin):
             for item in queryset.filter(id__in=(cut_item.pk, pasted_on.pk)):
                 item.save()
 
-            self.message_user(request,
-                ugettext('%s has been moved to a new position.') %
-                cut_item)
+            self.message_user(
+                request,
+                ugettext('%s has been moved to a new position.') % cut_item)
             return HttpResponse('OK')
 
         self.message_user(request, _('Did not understand moving instruction.'))
@@ -512,10 +534,9 @@ class TreeEditor(ExtensionModelAdmin):
                     logger.warning(
                         "Denied delete request by \"%s\" for object #%s",
                         request.user, obj.id)
-            self.message_user(request,
-                _("Successfully deleted %(count)d items.") % {
-                    "count": n
-                    })
+            self.message_user(
+                request,
+                _("Successfully deleted %(count)d items.") % {"count": n})
             # Return None to display the change list page again
             return None
         else:
