@@ -17,11 +17,17 @@ class RSSContent(models.Model):
     ``./manage.py update_rsscontent`` every couple of hours.
     """
 
-    title = models.CharField(_('title'), max_length=50,
-        help_text=_('The rss field is updated several times a day. A change in the title will only be visible on the home page after the next feed update.'))
+    title = models.CharField(
+        _('title'), max_length=50,
+        help_text=_(
+            'The rss field is updated several times a day.'
+            ' A change in the title will only be visible on the home page'
+            ' after the next feed update.'))
     link = models.URLField(_('link'))
-    rendered_content = models.TextField(_('pre-rendered content'), blank=True, editable=False)
-    last_updated = models.DateTimeField(_('last updated'), blank=True, null=True)
+    rendered_content = models.TextField(
+        _('pre-rendered content'), blank=True, editable=False)
+    last_updated = models.DateTimeField(
+        _('last updated'), blank=True, null=True)
     max_items = models.IntegerField(_('max. items'), default=5)
 
     class Meta:
@@ -37,14 +43,17 @@ class RSSContent(models.Model):
         entries = feed['entries'][:self.max_items]
         if date_format:
             for entry in entries:
-                entry.updated = time.strftime(date_format,
-                    entry.updated_parsed)
+                entry.updated = time.strftime(
+                    date_format, entry.updated_parsed)
 
-        self.rendered_content = render_to_string('content/rss/content.html', {
-            'feed_title': self.title,
-            'feed_link': feed['feed']['link'],
-            'entries': entries,
-            })
+        self.rendered_content = render_to_string(
+            'content/rss/content.html',
+            {
+                'feed_title': self.title,
+                'feed_link': feed['feed'].get('link'),
+                'entries': entries,
+            },
+        )
         self.last_updated = timezone.now()
 
         if save:
