@@ -2,8 +2,8 @@
 Base types for extensions refactor
 """
 
-import warnings
 from functools import wraps
+import inspect
 
 from django.contrib import admin
 from django.core.exceptions import ImproperlyConfigured
@@ -13,15 +13,6 @@ from feincms.utils import get_object
 
 
 class ExtensionsMixin(object):
-    @property
-    def _feincms_extensions(self):
-        warnings.warn(
-            'Start using _extensions instead of _feincms_extensions'
-            ' today!',
-            DeprecationWarning, stacklevel=2)
-
-        return set(self._extensions)
-
     @classmethod
     def register_extensions(cls, *extensions):
         """
@@ -44,7 +35,10 @@ class ExtensionsMixin(object):
 
             extension = None
 
-            if isinstance(ext, six.string_types):
+            if inspect.isclass(ext) and issubclass(ext, Extension):
+                extension = ext
+
+            elif isinstance(ext, six.string_types):
                 try:
                     extension = get_object(ext)
                 except (AttributeError, ImportError, ValueError):
@@ -74,13 +68,8 @@ class ExtensionsMixin(object):
             if hasattr(extension, 'handle_model'):
                 cls._extensions.append(extension(cls))
             else:
-                warnings.warn(
-                    '%r is a extension in legacy format.'
-                    ' Support for legacy extensions will be removed in'
-                    ' FeinCMS v1.9. Convert your extensions to'
-                    ' feincms.extensions.Extension now.' % extension,
-                    DeprecationWarning)
-                cls._extensions.append(LegacyExtension(cls, extension=extension))
+                raise ImproperlyConfigured(
+                    '%r is an invalid extension.' % extension)
 
 
 class Extension(object):
@@ -108,64 +97,6 @@ def _ensure_list(cls, attribute):
     setattr(cls, attribute, list(value))
 
 
-class LegacyExtension(Extension):
-    """
-    Wrapper for legacy extensions
-    """
-
-    #: Legacy extension function
-    extension = None
-
-    def handle_model(self):
-        self.fieldsets = []
-        self.filter_horizontal = []
-        self.filter_vertical = []
-        self.list_display = []
-        self.list_filter = []
-        self.raw_id_fields = []
-        self.search_fields = []
-
-        self.extension_options = []
-        self.known_keys = self.__dict__.keys()
-
-        self.extension(self.model, self)
-
-    def handle_modeladmin(self, modeladmin):
-        if self.fieldsets:
-            _ensure_list(modeladmin, 'fieldsets')
-            modeladmin.fieldsets.extend(self.fieldsets)
-        if self.filter_horizontal:
-            _ensure_list(modeladmin, 'filter_horizontal')
-            modeladmin.filter_horizontal.extend(self.filter_horizontal)
-        if self.filter_vertical:
-            _ensure_list(modeladmin, 'filter_vertical')
-            modeladmin.filter_vertical.extend(self.filter_vertical)
-        if self.list_display:
-            _ensure_list(modeladmin, 'list_display')
-            modeladmin.list_display.extend(self.list_display)
-        if self.list_filter:
-            _ensure_list(modeladmin, 'list_filter')
-            modeladmin.list_filter.extend(self.list_filter)
-        if self.raw_id_fields:
-            _ensure_list(modeladmin, 'raw_id_fields')
-            modeladmin.raw_id_fields.extend(self.raw_id_fields)
-        if self.search_fields:
-            _ensure_list(modeladmin, 'search_fields')
-            modeladmin.search_fields.extend(self.search_fields)
-
-        if self.extension_options:
-            for f in self.extension_options:
-                modeladmin.add_extension_options(*f)
-
-        for key, value in self.__dict__.items():
-            if key not in self.known_keys:
-                setattr(modeladmin.__class__, key, value)
-
-    def add_extension_options(self, *f):
-        if f:
-            self.extension_options.append(f)
-
-
 class ExtensionModelAdmin(admin.ModelAdmin):
     def __init__(self, *args, **kwargs):
         super(ExtensionModelAdmin, self).__init__(*args, **kwargs)
