@@ -50,8 +50,10 @@ class Region(object):
         of (content type key, beautified content type name) tuples
         """
 
-        return [(ct.__name__.lower(), ct._meta.verbose_name)
-                for ct in self._content_types]
+        return [
+            (ct.__name__.lower(), ct._meta.verbose_name)
+            for ct in self._content_types
+        ]
 
 
 @python_2_unicode_compatible
@@ -61,7 +63,8 @@ class Template(object):
     CMS object, most commonly a page.
     """
 
-    def __init__(self, title, path, regions, key=None, preview_image=None, **kwargs):
+    def __init__(self, title, path, regions, key=None, preview_image=None,
+                 **kwargs):
         # The key is what will be stored in the database. If key is undefined
         # use the template path as fallback.
         if not key:
@@ -105,7 +108,7 @@ class ContentProxy(object):
         self.db = item._state.db
         self._cache = {
             'cts': {},
-            }
+        }
 
     def _inherit_from(self):
         """
@@ -162,7 +165,7 @@ class ContentProxy(object):
     def _fetch_content_type_count_helper(self, pk, regions=None):
         tmpl = [
             'SELECT %d AS ct_idx, region, COUNT(id) FROM %s WHERE parent_id=%s'
-            ]
+        ]
         args = []
 
         if regions:
@@ -173,8 +176,10 @@ class ContentProxy(object):
         tmpl.append('GROUP BY region')
         tmpl = u' '.join(tmpl)
 
-        sql = ' UNION '.join([tmpl % (idx, cls._meta.db_table, pk)
-            for idx, cls in enumerate(self.item._feincms_content_types)])
+        sql = ' UNION '.join([
+            tmpl % (idx, cls._meta.db_table, pk)
+            for idx, cls in enumerate(self.item._feincms_content_types)
+        ])
         sql = 'SELECT * FROM ( ' + sql + ' ) AS ct ORDER BY ct_idx'
 
         cursor = connections[self.db].cursor()
@@ -198,19 +203,22 @@ class ContentProxy(object):
                 counts_by_type.setdefault(
                     self.item._feincms_content_types[ct_idx],
                     [],
-                    ).append((region, pk))
+                ).append((region, pk))
 
         # Resolve abstract to concrete content types
-        content_types = (cls for cls in self.item._feincms_content_types
-                 if issubclass(cls, tuple(types)))
+        content_types = (
+            cls for cls in self.item._feincms_content_types
+            if issubclass(cls, tuple(types))
+        )
 
         for cls in content_types:
             counts = counts_by_type.get(cls)
             if cls not in self._cache['cts']:
                 if counts:
-                    self._cache['cts'][cls] = list(cls.get_queryset(
-                        reduce(operator.or_, (
-                            Q(region=r[0], parent=r[1]) for r in counts))))
+                    self._cache['cts'][cls] = list(cls.get_queryset(reduce(
+                        operator.or_,
+                        (Q(region=r[0], parent=r[1]) for r in counts)
+                    )))
                 else:
                     self._cache['cts'][cls] = []
 
@@ -227,10 +235,12 @@ class ContentProxy(object):
                 for instance in content_list:
                     contents.setdefault(instance.region, []).append(instance)
 
-            self._cache['regions'] = dict((
-                region,
-                sorted(instances, key=lambda c: c.ordering),
-                ) for region, instances in contents.items())
+            self._cache['regions'] = dict(
+                (
+                    region,
+                    sorted(instances, key=lambda c: c.ordering),
+                ) for region, instances in contents.items()
+            )
 
         return self._cache['regions']
 
@@ -373,9 +383,10 @@ def create_base_model(inherit_from=models.Model):
             try:
                 field = cls._meta.get_field_by_name('template_key')[0]
             except (FieldDoesNotExist, IndexError):
-                cls.add_to_class('template_key',
+                cls.add_to_class(
+                    'template_key',
                     models.CharField(_('template'), max_length=255, choices=())
-                    )
+                )
                 field = cls._meta.get_field_by_name('template_key')[0]
 
                 def _template(self):
@@ -443,10 +454,16 @@ def create_base_model(inherit_from=models.Model):
                 ordering = ['ordering']
 
             def __str__(self):
-                return u'%s<pk=%s, parent=%s<pk=%s, %s>, region=%s, ordering=%d>' % (
-                    self.__class__.__name__, self.pk,
-                    self.parent.__class__.__name__, self.parent.pk, self.parent,
-                    self.region, self.ordering)
+                return (
+                    u'%s<pk=%s, parent=%s<pk=%s, %s>, region=%s,'
+                    u' ordering=%d>') % (
+                    self.__class__.__name__,
+                    self.pk,
+                    self.parent.__class__.__name__,
+                    self.parent.pk,
+                    self.parent,
+                    self.region,
+                    self.ordering)
 
             def render(self, **kwargs):
                 """
@@ -477,7 +494,7 @@ def create_base_model(inherit_from=models.Model):
                         return render_to_string('admin/feincms/fe_box.html', {
                             'content': self.render(**kwargs),
                             'identifier': self.fe_identifier(),
-                            })
+                        })
 
                 return self.render(**kwargs)
 
@@ -495,7 +512,7 @@ def create_base_model(inherit_from=models.Model):
                     self.__class__.__name__.lower(),
                     self.parent_id,
                     self.id,
-                    )
+                )
 
             def get_queryset(cls, filter_args):
                 return cls.objects.select_related().filter(filter_args)
@@ -517,7 +534,7 @@ def create_base_model(inherit_from=models.Model):
                 'parent': models.ForeignKey(cls, related_name='%(class)s_set'),
                 'region': models.CharField(max_length=255),
                 'ordering': models.IntegerField(_('ordering'), default=0),
-                }
+            }
 
             # create content base type and save reference on CMS class
 
@@ -568,7 +585,7 @@ def create_base_model(inherit_from=models.Model):
 
         @classmethod
         def create_content_type(cls, model, regions=None, class_name=None,
-                **kwargs):
+                                **kwargs):
             """
             This is the method you'll use to create concrete content types.
 
@@ -644,7 +661,8 @@ def create_base_model(inherit_from=models.Model):
                     RuntimeWarning)
 
             if not model._meta.abstract:
-                raise ImproperlyConfigured('Cannot create content type from'
+                raise ImproperlyConfigured(
+                    'Cannot create content type from'
                     ' non-abstract model (yet).')
 
             if not hasattr(cls, '_feincms_content_model'):
@@ -668,12 +686,13 @@ def create_base_model(inherit_from=models.Model):
                 # the blog and the page module).
                 '__module__': cls.__module__,
                 'Meta': Meta,
-                }
+            }
 
             new_type = type(
                 class_name,
                 (model, feincms_content_base,),
-                attrs)
+                attrs,
+            )
             cls._feincms_content_types.append(new_type)
             # For consistency's sake, also install the new type in the module
             setattr(sys.modules[cls.__module__], class_name, new_type)
@@ -685,8 +704,8 @@ def create_base_model(inherit_from=models.Model):
 
             # content types can be limited to a subset of regions
             if not regions:
-                regions = set([region.key for region
-                    in cls._feincms_all_regions])
+                regions = set([
+                    region.key for region in cls._feincms_all_regions])
 
             for region in cls._feincms_all_regions:
                 if region.key in regions:
@@ -765,7 +784,8 @@ def create_base_model(inherit_from=models.Model):
             # helper which can be used to ensure that either register_regions
             # or register_templates has been executed before proceeding
             if not hasattr(cls, 'template'):
-                raise ImproperlyConfigured('You need to register at least one'
+                raise ImproperlyConfigured(
+                    'You need to register at least one'
                     ' template or one region on %s.' % cls.__name__)
 
         @classmethod
@@ -774,9 +794,11 @@ def create_base_model(inherit_from=models.Model):
 
             # Check whether any content types have been created for this base
             # class
-            if (not hasattr(cls, '_feincms_content_types')
+            if (
+                    not hasattr(cls, '_feincms_content_types')
                     or not cls._feincms_content_types):
-                raise ImproperlyConfigured('You need to create at least one'
+                raise ImproperlyConfigured(
+                    'You need to create at least one'
                     ' content type for the %s model.' % cls.__name__)
 
         def copy_content_from(self, obj):
@@ -788,8 +810,8 @@ def create_base_model(inherit_from=models.Model):
 
             for cls in self._feincms_content_types:
                 for content in cls.objects.filter(parent=obj):
-                    new = copy_model_instance(content,
-                        exclude=('id', 'parent'))
+                    new = copy_model_instance(
+                        content, exclude=('id', 'parent'))
                     new.parent = self
                     new.save()
 
