@@ -10,14 +10,17 @@ from feincms import extensions
 
 class Extension(extensions.Extension):
     def handle_model(self):
-        self.model.add_to_class('excerpt', models.TextField(
-            _('excerpt'),
-            blank=True,
-            help_text=_('Add a brief excerpt summarizing the content'
-                ' of this page.')))
+        self.model.add_to_class(
+            'excerpt',
+            models.TextField(
+                _('excerpt'),
+                blank=True,
+                help_text=_(
+                    'Add a brief excerpt summarizing the content'
+                    ' of this page.')))
 
     def handle_modeladmin(self, modeladmin):
         modeladmin.add_extension_options(_('Excerpt'), {
             'fields': ('excerpt',),
             'classes': ('collapse',),
-            })
+        })
