@@ -19,6 +19,8 @@ from feincms._internal import monkeypatch_method
 class TypeRegistryMetaClass(type):
     """
     You can access the list of subclasses as <BaseClass>.types
+
+    TODO use NavigationExtension.__subclasses__() instead?
     """
 
     def __init__(cls, name, bases, attrs):
@@ -35,8 +37,8 @@ class PagePretender(object):
     navigation tree.
 
     For use as fake navigation page, you should at least define the following
-    parameters on creation: title, url, level. If using the translation extension,
-    also add language.
+    parameters on creation: title, url, level. If using the translation
+    extension, also add language.
     """
     pk = None
 
@@ -83,11 +85,12 @@ class NavigationExtension(six.with_metaclass(TypeRegistryMetaClass)):
 
     def children(self, page, **kwargs):
         """
-        This is the method which must be overridden in every navigation extension.
+        This is the method which must be overridden in every navigation
+        extension.
 
-        It receives the page the extension is attached to, the depth up to which
-        the navigation should be resolved, and the current request object if it
-        is available.
+        It receives the page the extension is attached to, the depth up to
+        which the navigation should be resolved, and the current request object
+        if it is available.
         """
 
         raise NotImplementedError
@@ -95,19 +98,24 @@ class NavigationExtension(six.with_metaclass(TypeRegistryMetaClass)):
 
 def navigation_extension_choices():
     for ext in NavigationExtension.types:
-        yield ('%s.%s' % (ext.__module__, ext.__name__), ext.name)
+        if (issubclass(ext, NavigationExtension)
+                and not ext is NavigationExtension):
+            yield ('%s.%s' % (ext.__module__, ext.__name__), ext.name)
 
 
 class Extension(extensions.Extension):
     ident = 'navigation'  # TODO actually use this
 
     def handle_model(self):
-        self.model.add_to_class('navigation_extension',
+        self.model.add_to_class(
+            'navigation_extension',
             models.CharField(
                 _('navigation extension'),
                 choices=navigation_extension_choices(),
                 blank=True, null=True, max_length=200,
-                help_text=_('Select the module providing subpages for this page if you need to customize the navigation.')))
+                help_text=_(
+                    'Select the module providing subpages for this page if'
+                    ' you need to customize the navigation.')))
 
         @monkeypatch_method(self.model)
         def extended_navigation(self, **kwargs):
@@ -124,4 +132,4 @@ class Extension(extensions.Extension):
         modeladmin.add_extension_options(_('Navigation extension'), {
             'fields': ('navigation_extension',),
             'classes': ('collapse',),
-            })
+        })
