@@ -74,13 +74,15 @@ class Thumbnailer(object):
             self.size,
             '.',
             format,
-            ])
+        ])
 
         if not storage.exists(miniature):
             generate = True
         else:
             try:
-                generate = storage.modified_time(miniature) < storage.modified_time(filename)
+                generate = (
+                    storage.modified_time(miniature)
+                    < storage.modified_time(filename))
             except (NotImplementedError, AttributeError):
                 # storage does NOT support modified_time
                 generate = False
@@ -109,7 +111,8 @@ class Thumbnailer(object):
             buf = BytesIO()
             if image.mode not in ('RGBA', 'RGB', 'L'):
                 image = image.convert('RGBA')
-            image.save(buf,
+            image.save(
+                buf,
                 format if format.lower() in ('jpg', 'jpeg', 'png') else 'jpeg',
                 quality=90)
             raw_data = buf.getvalue()
@@ -127,7 +130,8 @@ class Thumbnailer(object):
 
 
 class CropscaleThumbnailer(Thumbnailer):
-    THUMBNAIL_SIZE_RE = re.compile(r'^(?P<w>\d+)x(?P<h>\d+)(-(?P<x>\d+)x(?P<y>\d+))?$')
+    THUMBNAIL_SIZE_RE = re.compile(
+        r'^(?P<w>\d+)x(?P<h>\d+)(-(?P<x>\d+)x(?P<y>\d+))?$')
     MARKER = '_cropscale_'
 
     def generate(self, storage, original, size, miniature):
@@ -175,7 +179,8 @@ class CropscaleThumbnailer(Thumbnailer):
         buf = BytesIO()
         if image.mode not in ('RGBA', 'RGB', 'L'):
             image = image.convert('RGBA')
-        image.save(buf,
+        image.save(
+            buf,
             format if format.lower() in ('jpg', 'jpeg', 'png') else 'jpeg',
             quality=90)
         raw_data = buf.getvalue()
