@@ -14,8 +14,8 @@ Usage example::
         body = models.TextField()
 
 
-Print the titles of all news entries either in the current language (if available)
-or in any other language::
+Print the titles of all news entries either in the current language (if
+available) or in any other language::
 
     for news in News.objects.all():
         print news.translation.title
@@ -50,7 +50,8 @@ class _NoTranslation(object):
 
 def short_language_code(code=None):
     """
-    Extract the short language code from its argument (or return the default language code).
+    Extract the short language code from its argument (or return the default
+    language code).
 
     >>> short_language_code('de')
     'de'
@@ -70,8 +71,9 @@ def short_language_code(code=None):
 
 def is_primary_language(language=None):
     """
-    Returns true if current or passed language is the primary language for this site.
-    (The primary language is defined as the first language in settings.LANGUAGES.)
+    Returns true if current or passed language is the primary language for this
+    site.  (The primary language is defined as the first language in
+    settings.LANGUAGES.)
     """
 
     if not language:
@@ -92,7 +94,8 @@ def lookup_translations(language_code=None):
 
         instance_dict = {}
 
-        # Don't do anything for those who already have a cached translation available
+        # Don't do anything for those who already have a cached translation
+        # available
         for instance in qs:
             trans = cache.get(instance.get_translation_cache_key(lang_))
             if trans:
@@ -107,14 +110,22 @@ def lookup_translations(language_code=None):
         if not instance_dict:
             return
 
-        candidates = list(instance_dict.values())[0].translations.model._default_manager.all()
+        candidates = list(
+            instance_dict.values()
+        )[0].translations.model._default_manager.all()
 
         if instance_dict:
             _process(candidates, instance_dict, lang_, 'iexact')
         if instance_dict:
-            _process(candidates, instance_dict, settings.LANGUAGE_CODE, 'istartswith')
+            _process(
+                candidates,
+                instance_dict,
+                settings.LANGUAGE_CODE,
+                'istartswith',
+            )
         if instance_dict:
-            for candidate in candidates.filter(parent__pk__in=instance_dict.keys()):
+            for candidate in candidates.filter(
+                    parent__pk__in=instance_dict.keys()):
                 if candidate.parent_id in instance_dict:
                     _found(instance_dict, candidate)
 
@@ -130,12 +141,13 @@ def lookup_translations(language_code=None):
         del instance_dict[candidate.parent_id]
 
     def _process(candidates, instance_dict, lang_, op_):
-        for candidate in candidates.filter(
-                Q(parent__pk__in=instance_dict.keys()),
-                Q(**{'language_code__' + op_: lang_})
-                | Q(**{'language_code__' + op_: short_language_code(lang_)})
-                ).order_by('-language_code'):
+        candidates = candidates.filter(
+            Q(parent__pk__in=instance_dict.keys()),
+            Q(**{'language_code__' + op_: lang_})
+            | Q(**{'language_code__' + op_: short_language_code(lang_)})
+        ).order_by('-language_code')
 
+        for candidate in candidates:
             # The candidate's parent might already have a translation by now
             if candidate.parent_id in instance_dict:
                 _found(instance_dict, candidate)
@@ -169,13 +181,14 @@ class TranslatedObjectMixin(object):
             return queryset.filter(
                 Q(language_code__iexact=language_code)
                 | Q(language_code__iexact=short_language_code(language_code))
-                ).order_by('-language_code')[0]
+            ).order_by('-language_code')[0]
         except IndexError:
             try:
                 return queryset.filter(
                     Q(language_code__istartswith=settings.LANGUAGE_CODE)
-                    | Q(language_code__istartswith=short_language_code(settings.LANGUAGE_CODE))
-                    ).order_by('-language_code')[0]
+                    | Q(language_code__istartswith=short_language_code(
+                        settings.LANGUAGE_CODE))
+                ).order_by('-language_code')[0]
             except IndexError:
                 try:
                     return queryset.all()[0]
@@ -183,15 +196,20 @@ class TranslatedObjectMixin(object):
                     raise queryset.model.DoesNotExist
 
     def get_translation_cache_key(self, language_code=None):
-        """Return the cache key used to cache this object's translations so we can purge on-demand"""
+        """Return the cache key used to cache this object's translations so we
+        can purge on-demand"""
         if not language_code:
             language_code = translation.get_language()
-        return (('FEINCMS:%d:XLATION:' % getattr(settings, 'SITE_ID', 0)) +
-                '-'.join(['%s' % s for s in (
+        return (
+            ('FEINCMS:%d:XLATION:' % getattr(settings, 'SITE_ID', 0))
+            + '-'.join(
+                ['%s' % s for s in (
                     self._meta.db_table,
                     self.id,
                     language_code,
-                    )]))
+                )]
+            )
+        )
 
     def get_translation(self, language_code=None):
         if not language_code:
@@ -203,7 +221,8 @@ class TranslatedObjectMixin(object):
 
         if trans is None:
             try:
-                trans = self._get_translation_object(self.translations.all(), language_code)
+                trans = self._get_translation_object(
+                    self.translations.all(), language_code)
             except ObjectDoesNotExist:
                 trans = _NoTranslation
             cache.set(key, trans)
@@ -257,9 +276,10 @@ def Translation(model):
 
     class Inner(models.Model):
         parent = models.ForeignKey(model, related_name='translations')
-        language_code = models.CharField(_('language'), max_length=10,
-                choices=settings.LANGUAGES, default=settings.LANGUAGES[0][0],
-                editable=len(settings.LANGUAGES) > 1)
+        language_code = models.CharField(
+            _('language'), max_length=10,
+            choices=settings.LANGUAGES, default=settings.LANGUAGES[0][0],
+            editable=len(settings.LANGUAGES) > 1)
 
         class Meta:
             unique_together = ('parent', 'language_code')
